﻿function IncomingMailsViewModel()
{
    var self = this;
    self.totalIncomingEMails = ko.observable(0);
    self.incomingEMails = ko.observableArray();
    self.page = ko.observable(0);
    self.messagesPerPage = ko.observable(50);
    self.statusFilter = ko.observable("");
    self.isBusy = ko.observable(false);

    self.messagesPerPage.subscribe(function (newValue) {        
        self.page(0);
        self.countIncomingEMails();        
        self.getIncomingEMails();
    });

    self.statusFilter.subscribe(function (newValue) {
        self.page(0);
        self.countIncomingEMails();
        self.getIncomingEMails();
    });
    
    self.CurrentPage = ko.computed(function ()
    {
        return self.page() + 1;
    });

    self.TotalPages = ko.computed(function ()
    {
        return Math.floor(self.totalIncomingEMails() / self.messagesPerPage());
    });

    self.countIncomingEMails = function () {
        self.isBusy(true);
        var url = "/api/email2sms/count?status=" + self.statusFilter();
        $.ajax(
        {
            url: url,
            dataType: "json",
            success: function (data) {
                self.totalIncomingEMails(data);
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.getIncomingEMails = function () {
        self.isBusy(true);
        self.incomingEMails.removeAll();

        var url = "api/email2sms?status=" + self.statusFilter() + "&count=" + self.messagesPerPage() + "&page=" + self.page();
        $.ajax(
        {
            url: url,
            dataType: "json",
            success: function (data) {
                for (var i = 0; i < data.length; i++) {
                    var mail = CreateIncomingEMailFromJsonData(data[i]);
                    self.incomingEMails.push(mail);
                }
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.archiveIncomingEMail = function (eMail) {
        self.isBusy(true);
        var data = {};
        data.id = eMail.Id();
        data.action = "archive";

        $.ajax(
        {
            type: 'POST',
            url: '/api/email2sms/action',
            data: JSON.stringify(data),
            success: function (data) {
                self.incomingEMails.remove(eMail);
            },
            error: function (xhr, status, error) {
                alert("Failed to archive the message\n" + status);
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.nextPage = function () {
           
        if (self.page() < self.TotalPages()) {
            self.page(self.page() + 1);
            self.countIncomingEMails();
            self.getIncomingEMails();
        }
    };

    self.previousPage = function () {
        if (self.page() > 0) {
            self.page(self.page() - 1);
            self.countIncomingEMails();
            self.getIncomingEMails();
        }
    };

    self.firstPage = function ()
    {
        self.page(0);
        self.countIncomingEMails();
        self.getIncomingEMails();
    };

    self.lastPage = function ()
    {
        self.page(self.TotalPages());
        self.countIncomingEMails();
        self.getIncomingEMails();
    };
}



