﻿function IncomingSmsViewModel()
{
    var self = this;
    self.totalIncomingSms = ko.observable(0);
    self.incomingSms = ko.observableArray();
    self.page = ko.observable(0);
    self.messagesPerPage = ko.observable(50);
    self.statusFilter = ko.observable("");
    self.isBusy = ko.observable(false);

    self.messagesPerPage.subscribe(function (newValue) {
        self.page(0);
        self.countIncomingSms();
        self.getIncomingSms();
    });

    self.statusFilter.subscribe(function (newValue) {
        self.page(0);
        self.countIncomingSms();
        self.getIncomingSms();
    });

    self.CurrentPage = ko.computed(function () {
        return self.page() + 1;
    });

    self.TotalPages = ko.computed(function () {
        return Math.floor(self.totalIncomingSms() / self.messagesPerPage());
    });
            
    self.countIncomingSms = function () {
        self.isBusy(true);
        var url = "/api/sms2email/count?status=" + self.statusFilter();

        $.ajax(
        {
            url: url,
            dataType: "json",
            success: function (data) {
                self.totalIncomingSms(data);
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.getIncomingSms = function () {
        self.isBusy(true);
        self.incomingSms.removeAll();

        var url = "/api/sms2email?status=" + self.statusFilter() + "&count=" + self.messagesPerPage() + "&page=" + self.page();
        $.ajax(
        {
            url: url,
            dataType: "json",
            success: function (data) {
                for (var i = 0; i < data.length; i++) {
                    var mail = CreateIncomingSmsFromJsonData(data[i]);
                    self.incomingSms.push(mail);
                }
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.archiveIncomingSms = function (sms) {
        self.isBusy(true);
        var data = {};
        data.id = sms.Id();
        data.action = "archive";

        $.ajax(
        {
            type: 'POST',
            url: '/api/sms2email/action',
            data: JSON.stringify(data),
            success: function (data) {
                self.incomingSms.remove(sms);
            },
            error: function (xhr, status, error) {
                alert("Failed to archive the message\n" + status + "\n" + error);
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    };

    self.nextPage = function () {
        if (self.page() < self.TotalPages()) {
            self.page(self.page() + 1);
            self.countIncomingSms();
            self.getIncomingSms();
        }
    };

    self.previousPage = function () {
        if (self.page() > 0) {
            self.page(self.page() - 1);
            self.countIncomingSms();
            self.getIncomingSms();
        }
    };

    self.firstPage = function () {
        self.page(0);
        self.countIncomingSms();
        self.getIncomingSms();
    };

    self.lastPage = function () {
        self.page(self.TotalPages());
        self.countIncomingSms();
        self.getIncomingSms();
    };
}



