﻿function KnownUsersViewModel()
{
    var self = this;
    this.knownUsers = ko.observableArray();
    this.selectedUser = ko.observable(null);
    this.editModeEnabled = ko.observable(false);
    this.newUser = ko.observable(null);
    self.isBusy = ko.observable(false);

    this.getKnownUsers = function ()
    {
        self.isBusy(true);
        self.knownUsers.removeAll();
        $.ajax(
        {
            url: "/api/knownusers",
            dataType: "json",
            success: function (data)
            {
                for (var i = 0; i < data.length; i++) {
                    var user = CreateKnownUserFromJsonData(data[i]);
                    self.knownUsers.push(user);
                }
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    }

    this.displayKnownUser = function (user)
    {
        self.editModeEnabled(false);
        self.selectedUser(user);
    }

    this.enableEditMode = function ()
    {
        self.editModeEnabled(true);
    }

    this.disableEditMode = function ()
    {
        self.editModeEnabled(false);

        if (self.newUser())
        {
            self.knownUsers.remove(self.newUser());
            self.newUser(null);
            self.selectedUser(null);
        }
    }
    
    this.saveSelectedUser = function ()
    {
        self.isBusy(true);
        $.ajax(
        {
            url: "/api/knownusers/save",
            type: "POST",
            dataType: "json",
            data: ko.toJSON(self.selectedUser()),
            async: true,
            success: function (result)
            {
                if (result) {
                    if (result.Id === 0)
                        alert("Failed to save the user");
                    else {

                        self.selectedUser().Id(result.Id);
                        self.editModeEnabled(false);
                        self.newUser(null);
                    }
                }
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    }

    this.deleteSelectedUser = function ()
    {
        self.isBusy(true);
        $.ajax(
        {
            url: "/api/knownusers/delete",
            type: "POST",
            dataType: "json",
            data: ko.toJSON(self.selectedUser()),
            success: function (result)
            {
                if (result) {
                    self.knownUsers.remove(self.selectedUser());
                    self.selectedUser(null);
                }
            },
            complete: function (x, s) { self.isBusy(false); }
        });
    }

    this.addKnownUser = function ()
    {
        if (!self.newUser()) {

            self.newUser(new KnownUser());
            self.knownUsers.push(self.newUser());
            self.selectedUser(self.newUser());
            self.editModeEnabled(true);
        }
    }
}



