﻿function KnownUser() {
    var self = this;
    self.Id = ko.observable(0);
    self.Initials = ko.observable("");
    self.Name = ko.observable("");
    self.Surname = ko.observable("");
    self.EMailAddress = ko.observable("");
    self.MobileNumber = ko.observable("");
    self.IsAllowedToSendEMail = ko.observable(false);
    self.IsAllowedToSendSms = ko.observable(false);
    self.CanReceiveEMail = ko.observable(false);
    self.CanReceiveSms = ko.observable(false);
};

function IncomingEMail() {
    var self = this;
    self.Id = ko.observable(0);
    self.EMailId = ko.observable(0);
    self.ServerDomain = ko.observable("");
    self.ServerAddress = ko.observable("");
    self.DateReceived = ko.observable(null);
    self.SenderId = ko.observable(0);
    self.SenderEMailAddress = ko.observable("");
    self.SenderName = ko.observable("");
    self.SenderSurname = ko.observable("");
    self.RecipientId = ko.observable(0);
    self.RecipientInitials = ko.observable("");
    self.RecipientAddress = ko.observable("");
    self.RecipientMobileNumber = ko.observable("");
    self.RecipientEMailAddress = ko.observable("");
    self.RecipientName = ko.observable("");
    self.RecipientSurname = ko.observable("");
    self.Subject = ko.observable("");
    self.Headers = ko.observable("");
    self.DeliveryStatus = ko.observable("");

    self.SenderFullName = ko.computed(function () {
        return self.SenderName() + " " + self.SenderSurname();
    });

    self.RecipientFullName = ko.computed(function () {
        var name = self.RecipientName() ? self.RecipientName() : "";
        name += self.RecipientSurname() ? " " + self.RecipientSurname() : "";
        //name += self.RecipientMobileNumber() ? " (" + self.RecipientMobileNumber() + ")" : "";

        if (!name) {
            name = self.RecipientMobileNumber();
        }
        return name;
    });

    self.NiceDateReceived = ko.computed(function () {
        return new Date(self.DateReceived()).toLocalTime().format("d/m/y H:i:s");
    });

    self.DateReceivedObject = ko.computed(function () {
        return new Date(self.DateReceived()).toLocalTime();
    });
};

function IncomingSms() {
    var self = this;
    self.Id = ko.observable();
    self.SenderMobileNumber = ko.observable("");
    self.RecipientInitials = ko.observable("");
    self.Text = ko.observable("");
    self.DateReceived = ko.observable(null);
    self.IsServerGenerated = ko.observable(false);
    self.RecipientId = ko.observable();
    self.RecipientEMailAddress = ko.observable("");
    self.RecipientName = ko.observable("");
    self.RecipientSurname = ko.observable("");
    self.SenderId = ko.observable();
    self.SenderEMailAddress = ko.observable("");
    self.SenderName = ko.observable("");
    self.SenderSurname = ko.observable("");
    self.DeliveryStatus = ko.observable("");

    self.SenderFullName = ko.computed(function () {
        var name = self.SenderName() ? self.SenderName() : "";
        name += self.SenderSurname() ? " " + self.SenderSurname() : "";

        if (!name)
            name = self.SenderMobileNumber();

        return name;
    });

    self.RecipientFullName = ko.computed(function () {
        var name = self.RecipientName() ? self.RecipientName() : "";
        name += self.RecipientSurname() ? " " + self.RecipientSurname() : "";

        return name;
    });

    self.NiceDateReceived = ko.computed(function () {
        return new Date(self.DateReceived()).toLocalTime().format("d/m/y H:i:s");
    });

    self.DateReceivedObject = ko.computed(function () {
        return new Date(self.DateReceived()).toLocalTime();
    });

    self.SingleLineText = ko.computed(function () {
        return self.Text().replace('\n', ' ').replace('\r', ' ');
    });
};

function DeliveryAttempt() {
    var self = this;
    self.Date = ko.observable();
    self.Status = ko.observable("");
    self.Error = ko.observable("");
    self.Ignore = ko.observable(false);

    self.NiceDate = ko.computed(function () {
        return new Date(self.Date()).toLocalTime().format("d/m/y H:i:s");
    });
};

function Configuration() {
    var self = this;
    self.Id = ko.observable();
    self.Domain = ko.observable();
    self.SendMailRetryCount = ko.observable(0);
    self.SendSmsRetryCount = ko.observable(0);
    self.ModemSerialPort = ko.observable();
    self.ModemBaudrate = ko.observable();
    self.SimPin = ko.observable();
    self.OutgoingSmtpHostname = ko.observable();
    self.OutgoingSmtpPort = ko.observable();
    self.OutgoingSmtpUsername = ko.observable();
    self.OutgoingSmtpPassword = ko.observable();
    self.OutgoingSmtpEnableSsl = ko.observable();
    self.AllowTemporaryRecipients = ko.observable();
    self.TemporaryRecipientExistenseDuration = ko.observable();
    self.Timezone = ko.observable("");
    self.IncomingSmsValidityPeriod = ko.observable(1);
    self.IncomingEMailValidityPeriod = ko.observable(1);
    self.PauseDelivery = ko.observable();
    self.WebServerFileCacheMaxSize = ko.observable(0);
};

function CreateKnownUserFromJsonData(data) {
    var user = new KnownUser();
    user.Id(data.Id);
    user.Initials(data.Initials);
    user.Name(data.Name);
    user.Surname(data.Surname);
    user.EMailAddress(data.EMailAddress);
    user.MobileNumber(data.MobileNumber);
    user.IsAllowedToSendEMail(data.IsAllowedToSendEMail);
    user.IsAllowedToSendSms(data.IsAllowedToSendSms);
    user.CanReceiveEMail(data.CanReceiveEMail);
    user.CanReceiveSms(data.CanReceiveSms);
    return user;
};

function CreateDeliveryAttemptFromJsonData(data) {
    var attempt = new DeliveryAttempt();
    attempt.Date(data.Date);
    attempt.Status(data.Status);
    attempt.Error(data.Error);
    attempt.Ignore(data.Ignore);
    return attempt;
};

function CreateIncomingEMailFromJsonData(data) {
    var mail = new IncomingEMail();
    mail.Id(data.Id);
    mail.EMailId(data.EMailId);
    mail.DateReceived(data.DateReceived);
    mail.RecipientAddress(data.RecipientAddress);
    mail.RecipientEMailAddress(data.RecipientEMailAddress);
    mail.RecipientId(data.RecipientId);
    mail.RecipientInitials(data.RecipientInitials);
    mail.RecipientMobileNumber(data.RecipientMobileNumber);
    mail.RecipientName(data.RecipientName);
    mail.RecipientSurname(data.RecipientSurname);
    mail.SenderId(data.senderid);
    mail.SenderEMailAddress(data.SenderEMailAddress);
    mail.SenderName(data.SenderName);
    mail.SenderSurname(data.SenderSurname);
    mail.ServerAddress(data.ServerAddress);
    mail.ServerDomain(data.ServerDomain);
    mail.Subject(data.Subject);
    mail.Headers(data.Headers);
    mail.DeliveryStatus(data.DeliveryStatus);
    return mail;
};

function CreateIncomingSmsFromJsonData(data) {
    var sms = new IncomingSms();
    sms.Id(data.Id);
    sms.DateReceived(data.DateReceived);
    sms.IsServerGenerated(data.IsServerGenerated);
    sms.RecipientEMailAddress(data.RecipientEMailAddress);
    sms.RecipientId(data.recipientId);
    sms.RecipientInitials(data.RecipientInitials);
    sms.RecipientName(data.RecipientName);
    sms.RecipientSurname(data.RecipientSurname);
    sms.SenderId(data.SenderId);
    sms.SenderEMailAddress(data.SenderEMailAddress);
    sms.SenderMobileNumber(data.SenderMobileNumber);
    sms.SenderName(data.SenderName);
    sms.SenderSurname(data.SenderSurname);
    sms.Text(data.Text);
    sms.DeliveryStatus(data.DeliveryStatus);
    return sms;

};

function CreateConfigurationFromJsonData(data) {
    var configuration = new Configuration();
    configuration.Id(data.Id);
    configuration.Domain(data.Domain);
    configuration.SendMailRetryCount(data.SendMailRetryCount);
    configuration.SendSmsRetryCount(data.SendSmsRetryCount);
    configuration.ModemSerialPort(data.ModemSerialPort);
    configuration.ModemBaudrate(data.ModemBaudRate);
    configuration.SimPin(data.SimPin);
    configuration.OutgoingSmtpHostname(data.OutgoingSmtpHostname);
    configuration.OutgoingSmtpPort(data.OutgoingSmtpPort);
    configuration.OutgoingSmtpUsername(data.OutgoingSmtpUsername);
    configuration.OutgoingSmtpPassword(data.OutgoingSmtpPassword);
    configuration.OutgoingSmtpEnableSsl(data.OutgoingSmtpEnableSsl);
    configuration.AllowTemporaryRecipients(data.AllowTemporaryRecipients);
    configuration.TemporaryRecipientExistenseDuration(data.TemporaryRecipientExistenseDuration);
    configuration.Timezone(data.Timezone);
    configuration.IncomingSmsValidityPeriod(data.IncomingSmsValidityPeriod);
    configuration.IncomingEMailValidityPeriod(data.IncomingEMailValidityPeriod);
    configuration.PauseDelivery(data.PauseDelivery);
    configuration.WebServerFileCacheMaxSize(data.WebServerFileCacheMaxSize);
    return configuration;
};